summaryrefslogtreecommitdiffstats
path: root/src/H5FDdirect.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/H5FDdirect.c')
-rw-r--r--src/H5FDdirect.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/src/H5FDdirect.c b/src/H5FDdirect.c
index 7275bb5..25006ac 100644
--- a/src/H5FDdirect.c
+++ b/src/H5FDdirect.c
@@ -549,10 +549,10 @@ H5FD__direct_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxad
* is to handle correctly the case that the file is in a different file system
* than the one where the program is running.
*/
/* NOTE: Use HDmalloc and HDfree here to ensure compatibility with
* posix_memalign.
*/
- buf1 = HDmalloc(sizeof(int));
+ buf1 = malloc(sizeof(int));
if (posix_memalign(&buf2, file->fa.mboundary, file->fa.fbsize) != 0)
HGOTO_ERROR(H5E_RESOURCE, H5E_CANTALLOC, NULL, "posix_memalign failed")
@@ -591,9 +591,9 @@ H5FD__direct_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxad
}
if (buf1)
- HDfree(buf1);
+ free(buf1);
if (buf2)
- HDfree(buf2);
+ free(buf2);
/* Set return value */
ret_value = (H5FD_t *)file;
@@ -1003,8 +1003,8 @@ H5FD__direct_read(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_U
addr = (haddr_t)(((addr + size - 1) / _fbsize + 1) * _fbsize);
if (copy_buf) {
- /* Free with HDfree since it came from posix_memalign */
- HDfree(copy_buf);
+ /* Free with free since it came from posix_memalign */
+ free(copy_buf);
copy_buf = NULL;
} /* end if */
}
@@ -1015,9 +1015,9 @@ H5FD__direct_read(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_U
done:
if (ret_value < 0) {
- /* Free with HDfree since it came from posix_memalign */
+ /* Free with free since it came from posix_memalign */
if (copy_buf)
- HDfree(copy_buf);
+ free(copy_buf);
/* Reset last file I/O information */
file->pos = HADDR_UNDEF;
@@ -1230,8 +1230,8 @@ H5FD__direct_write(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_
buf = (const char *)buf + size;
if (copy_buf) {
- /* Free with HDfree since it came from posix_memalign */
- HDfree(copy_buf);
+ /* Free with free since it came from posix_memalign */
+ free(copy_buf);
copy_buf = NULL;
} /* end if */
}
@@ -1244,9 +1244,9 @@ H5FD__direct_write(H5FD_t *_file, H5FD_mem_t H5_ATTR_UNUSED type, hid_t H5_ATTR_
done:
if (ret_value < 0) {
- /* Free with HDfree since it came from posix_memalign */
+ /* Free with free since it came from posix_memalign */
if (copy_buf)
- HDfree(copy_buf);
+ free(copy_buf);
/* Reset last file I/O information */
file->pos = HADDR_UNDEF;
@@ -549,10 +549,10 @@ H5FD__direct_open(const char *name, unsigned flags, hid_t fapl_id, haddr_t maxad
* than the one where the program is running.
*/
- /* NOTE: Use HDmalloc and HDfree here to ensure compatibility with
- * posix_memalign.
+ /* NOTE: Use malloc and free here to ensure compatibility with
+ * posix_memalign().
*/